@@ -1,8 +1,4 @@
 # -*- coding: utf-8 -*-
-import os
-import sys
-sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
-
 from pytest import raises
 
 from astral import AstralGeocoder
@@ -10,7 +6,7 @@ from astral import AstralGeocoder
 def test_Group():
     db = AstralGeocoder()
     _e = db.europe
-    
+
 def test_UnknownGroup():
     with raises(AttributeError):
         db = AstralGeocoder()
@@ -26,7 +22,7 @@ def test_GroupContainment():
 
 def test_CityCountry():
     city_name = 'Birmingham,England'
-    
+
     db = AstralGeocoder()
     city = db[city_name]
     assert city.name == 'Birmingham'
@@ -39,7 +35,7 @@ def test_MultiCountry():
 
 def test_MultiCountryWithCountry():
     """Test for fix made due to bug report from Klaus Alexander Seistrup"""
-    
+
     db = AstralGeocoder()
     city = db['Abu Dhabi,United Arab Emirates']
     assert city.name == 'Abu Dhabi'
@@ -49,13 +45,13 @@ def test_MultiCountryWithCountry():
 
 def test_Adelaide():
     """Test for fix made due to bug report from Klaus Alexander Seistrup"""
-    
+
     db = AstralGeocoder()
     _city = db['Adelaide']
 
 def test_CandianCities():
     db = AstralGeocoder()
-    
+
     city = db['Fredericton']
     assert city.elevation == 8
 
@@ -63,6 +59,6 @@ def test_AllCities():
     db = AstralGeocoder()
     locations = db.locations
     locations.sort()
-    
+
     for city_name in locations:
         _city = db[city_name]
