@@ -1,12 +1,8 @@
 # -*- coding: utf-8 -*-
 
 from __future__ import unicode_literals
-import os
-import sys
-sys.path.insert(0,
-                os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
 
-import pytest 
+import pytest
 import astral
 import datetime
 
